@@ -109,12 +109,12 @@ def get_editable_root() -> tuple[Path, Path] | None:
     if (
         not is_editable_install()
         or r"/startdir/src/sage" == ""
-        or r"/startdir/src/sage/.mesonpy-5ezcd336" == ""
+        or r"/startdir/src/sage/.mesonpy-fyblzv9j" == ""
     ):
         return None
 
     src = Path(r"/startdir/src/sage").resolve()
-    build = Path(r"/startdir/src/sage/.mesonpy-5ezcd336").resolve()
+    build = Path(r"/startdir/src/sage/.mesonpy-fyblzv9j").resolve()
     if src.is_dir() and build.is_dir():
         return src, build
     return None
